@@ -41,8 +41,8 @@ def create_all_models() -> List[MotorcycleModel]:
 
 if __name__ == "__main__":
     create_motorcycle_model("xlsx_lib/files/FICHA T MAX 560 2020.xlsx")
-    create_motorcycle_model("xlsx_lib/files/FICHA XVS 950 STAR ´14.xlsx")
-    create_motorcycle_model("xlsx_lib/files/FICHA FORZA 125 ´15 .xlsx")
+    # create_motorcycle_model("xlsx_lib/files/FICHA XVS 950 STAR ´14.xlsx")
+    # create_motorcycle_model("xlsx_lib/files/FICHA FORZA 125 ´15 .xlsx")
 
     # create_motorcycle_model("/home/tomasdarioam/projects/infomoto/vps-backup/a1/_data/gilera/gp-800-08-14/FICHA GP 800 ´08 ´14.xlsx")
     # create_motorcycle_model("/home/tomasdarioam/projects/infomoto/vps-backup/a1/_data/gilera/sc-125-06/FICHA  SC 125  ´06 -.xlsx")
